@@ -37,6 +37,8 @@ from data_science_helper.model import custom_bagging__lgb_model as cb_lgb_model
 
 from sklearn.metrics import f1_score
 
+from data_science_helper.model import lgb_model as l
+
 #import src.Prj_Core.core_helper.model.neg_bagging_fraction__lgb_model as nbf_lgb_model
 #import src.Prj_Core.core_helper.model.scale_pos_weight__lgb_model as spw_lgb_model
 #import src.Prj_Core.core_helper.model.custom_bagging__lgb_model as cb_lgb_model
@@ -53,18 +55,19 @@ def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=
     params.update({"objective":'binary'})
             
     args = {'X_train':X_train, 'y_train': y_train, 'X_test': X_test, 'y_test': y_test, 'params':params,
-            "metric":metric,"num_rounds":num_rounds,"early_stop":early_stop,"log":log,"random_state":random_state,"api":api ,
+            "metric":metric,"num_rounds":num_rounds,"early_stop":early_stop,"log":log,"random_state":random_state,"api":api ,"strategy":strategy,
             "url":url }     
     
 
-    
+    model , y_prob_uno   = l.modelar(**args)
+    '''
     if (strategy=="neg_bagging_fraction__lgb_model"):
-        model , y_prob_uno   = nbf_lgb_model.modelar(**args)
+        model , y_prob_uno   = l.modelar(**args)
     if (strategy=="scale_pos_weight__lgb_model"):
-        model , y_prob_uno   = spw_lgb_model.modelar(**args)
+        model , y_prob_uno   = l.modelar(**args)
     if (strategy=="custom_bagging__lgb_model"):
         model , y_prob_uno   = cb_lgb_model.modelar(X_train,y_train,X_test,y_test,url)
-        
+    '''    
     umbral_opt = g.get_opt_threshold(y_test,y_prob_uno)
 
     kpis = generar_reporte(model,y_prob_uno,X_test,y_test,None,url,print_consola)
