@@ -19,6 +19,57 @@ from sklearn.metrics import f1_score
 #import src.Prj_Core.core_helper.model.general as g
 from data_science_helper.model import general as g
 
+import time
+
+
+def get_neg_bagging_fraction_params(y_train=None,params=None,log=0):
+    
+    N_p = y_train[y_train==1].count()
+    N_n = y_train[y_train==0].count()
+    #T_minimo= 43000
+    T_minimo = get_Total_min_to_train(N_p)
+    
+    if  log is not None and log>0 :
+    
+        print("T_minimo : ",T_minimo)
+        print("N_p : ",N_p)
+        print("N_n : ",N_n)
+    
+    alpha = (T_minimo-N_p)/N_n
+    if params is None:
+        params = get_default_params()
+        
+    params['pos_bagging_fraction'] = 1
+    params['neg_bagging_fraction'] = alpha
+    params['scale_pos_weight'] = (alpha*N_n)/N_p
+    return params
+
+
+def get_scale_pos_weight_params(y_train,params):
+    
+    N_p = y_train[y_train==1].count()
+    N_n = y_train[y_train==0].count()
+    
+    T_minimo = get_Total_min_to_train(N_p)
+    
+    alpha = (T_minimo-N_p)/N_n
+    if params is None:
+        params = get_default_params()
+        
+    params['pos_bagging_fraction'] = 1
+    params['neg_bagging_fraction'] = 1
+    params['scale_pos_weight'] = N_n/N_p
+
+    return params
+
+def get_Total_min_to_train(N_p):
+    T_minimo = 10000 
+    
+    while N_p>=T_minimo:
+      T_minimo = T_minimo + 30000
+
+    return T_minimo
+
 
 def lgb_f1_score(y_hat, data):
     y_true = data.get_label()
@@ -100,6 +151,38 @@ def get_default_params_old():
     return params
 
 
+def modelar(X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric=None,num_rounds=None,early_stop=None,log=None,random_state=42,api="train_api",strategy="",url=None):
+    start = time.time()
+    model = None
+    
+    if (strategy=="neg_bagging_fraction__lgb_model"):
+        params = get_neg_bagging_fraction_params(y_train,params)
+        
+    if (strategy=="scale_pos_weight__lgb_model"):
+        params = get_neg_bagging_fraction_params(y_train,params)
+
+    
+    if api=="train_api":
+
+        model = lgb_model_train(X_train,y_train,X_test,y_test,params=params,metric=metric,num_rounds=num_rounds,early_stop=early_stop,log=log)
+        y_prob_uno = model.predict(X_test, num_iteration=model.best_iteration) 
+        
+    elif api=="skl_api":
+        model = lgb_model_skl(X_train,y_train,X_test,y_test,params=params,metric=metric)        
+        predicted_probas = model.predict_proba(X_test) 
+        y_prob_uno = predicted_probas[:,1]
+        
+    if url is not None:
+        g.save_model(model,url)
+        g.save_json(params,url+"/params.json")
+    
+    
+    if model is None:
+        raise Exception("Modelo no implementado")
+    
+    return model , y_prob_uno 
+
+
 def lgb_model_skl(X_train,y_train,X_test,y_test,metric='average_precision',params=None):
 
     fn_eval = g.get_fn_eval(metric)
